# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `matop` Chapter.
"""

# NAG Copyright 2017-2019.

from ..base import utils

real_symm_posdef_inv = utils._EngineState._get_symbol('f01abf')
real_symm_posdef_inv.restype = None
real_symm_posdef_inv.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Output, b[ldb, n].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Workspace, z[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_posdef_inv_noref = utils._EngineState._get_symbol('f01adf')
real_symm_posdef_inv_noref.restype = None
real_symm_posdef_inv_noref.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_pseudinv = utils._EngineState._get_symbol('f01blf')
real_gen_pseudinv.restype = None
real_gen_pseudinv.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, t.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, aijmax[n].
    utils._BYREF_INT, # Output, irank.
    utils._EngineIntArrayType.c_type, # Output, inc[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, d[m].
    utils._EngineFloat64ArrayType.c_type, # Workspace, u[ldu, n].
    utils._BYREF_INT, # Input, ldu.
    utils._EngineFloat64ArrayType.c_type, # Workspace, du[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_sparse_lu = utils._EngineState._get_symbol('f01brf')
real_gen_sparse_lu.restype = None
real_gen_sparse_lu.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[licn].
    utils._BYREF_INT, # Input, licn.
    utils._EngineIntArrayType.c_type, # Input/Output, irn[lirn].
    utils._BYREF_INT, # Input, lirn.
    utils._EngineIntArrayType.c_type, # Input/Output, icn[licn].
    utils._BYREF_FLOAT64, # Input, pivot.
    utils._EngineIntArrayType.c_type, # Output, ikeep[5*n].
    utils._EngineIntArrayType.c_type, # Workspace, iw[8*n].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._BYREF_LOGICAL, # Input, lblock.
    utils._BYREF_LOGICAL, # Input, grow.
    utils._EngineLogicalArrayType.c_type, # Input, abort[4].
    utils._EngineIntArrayType.c_type, # Output, idisp[10].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_sparse_lu_reuse = utils._EngineState._get_symbol('f01bsf')
real_gen_sparse_lu_reuse.restype = None
real_gen_sparse_lu_reuse.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nz.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[licn].
    utils._BYREF_INT, # Input, licn.
    utils._EngineIntArrayType.c_type, # Input, ivect[nz].
    utils._EngineIntArrayType.c_type, # Input, jvect[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, icn[licn].
    utils._EngineIntArrayType.c_type, # Input, ikeep[5*n].
    utils._EngineIntArrayType.c_type, # Workspace, iw[5*n].
    utils._EngineFloat64ArrayType.c_type, # Output, w[n].
    utils._BYREF_LOGICAL, # Input, grow.
    utils._BYREF_FLOAT64, # Input, eta.
    utils._BYREF_FLOAT64, # Output, rpmin.
    utils._BYREF_LOGICAL, # Input, abort.
    utils._EngineIntArrayType.c_type, # Input, idisp[2].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_posdef_fac = utils._EngineState._get_symbol('f01buf')
real_symm_posdef_fac.restype = None
real_symm_posdef_fac.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w[m1].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_posdef_geneig = utils._EngineState._get_symbol('f01bvf')
real_symm_posdef_geneig.restype = None
real_symm_posdef_geneig.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ma1.
    utils._BYREF_INT, # Input, mb1.
    utils._BYREF_INT, # Input, m3.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, n].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Workspace, v[ldv, m3].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Workspace, w[m3].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matmul = utils._EngineState._get_symbol('f01ckf')
real_gen_matmul.restype = None
real_gen_matmul.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Output, a[n, p].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[n, m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[m, p].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, p.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Workspace, z[iz].
    utils._BYREF_INT, # Input, iz.
    utils._BYREF_INT, # Input, opt.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_trans_inplace = utils._EngineState._get_symbol('f01crf')
real_gen_trans_inplace.restype = None
real_gen_trans_inplace.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[mn].
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, mn.
    utils._EngineIntArrayType.c_type, # Workspace, move[lmove].
    utils._BYREF_INT, # Input, lmove.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_addsub = utils._EngineState._get_symbol('f01ctf')
real_addsub.restype = None
real_addsub.argtypes = (
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, transb(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, beta.
    utils._EngineFloat64ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineFloat64ArrayType.c_type, # Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transb.
)

complex_addsub = utils._EngineState._get_symbol('f01cwf')
complex_addsub.restype = None
complex_addsub.argtypes = (
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_STRING, # Input, transb(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_COMPLEX128, # Input, beta.
    utils._EngineComplex128ArrayType.c_type, # Input, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._EngineComplex128ArrayType.c_type, # Output, c[ldc, *].
    utils._BYREF_INT, # Input, ldc.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transb.
)

real_tri_matmul_inplace = utils._EngineState._get_symbol('f01dgf')
real_tri_matmul_inplace.restype = None
real_tri_matmul_inplace.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_FLOAT64, # Input, alpha.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
)

complex_tri_matmul_inplace = utils._EngineState._get_symbol('f01duf')
complex_tri_matmul_inplace.restype = None
complex_tri_matmul_inplace.argtypes = (
    utils._BYREF_STRING, # Input, side(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, transa(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_COMPLEX128, # Input, alpha.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of side.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transa.
)

real_gen_matrix_exp = utils._EngineState._get_symbol('f01ecf')
real_gen_matrix_exp.restype = None
real_gen_matrix_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_symm_matrix_exp = utils._EngineState._get_symbol('f01edf')
real_symm_matrix_exp.restype = None
real_symm_matrix_exp.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

real_symm_matrix_fun_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Output, fx[n].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_symm_matrix_fun = utils._EngineState._get_symbol('f01eff')
real_symm_matrix_fun.restype = None
real_symm_matrix_fun.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    real_symm_matrix_fun_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

real_gen_matrix_log = utils._EngineState._get_symbol('f01ejf')
real_gen_matrix_log.restype = None
real_gen_matrix_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, imnorm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_fun_std = utils._EngineState._get_symbol('f01ekf')
real_gen_matrix_fun_std.restype = None
real_gen_matrix_fun_std.argtypes = (
    utils._BYREF_STRING, # Input, fun(len=*).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, imnorm.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fun.
)

real_gen_matrix_fun_num_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_matrix_fun_num = utils._EngineState._get_symbol('f01elf')
real_gen_matrix_fun_num.restype = None
real_gen_matrix_fun_num.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    real_gen_matrix_fun_num_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, imnorm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_fun_usd_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_matrix_fun_usd = utils._EngineState._get_symbol('f01emf')
real_gen_matrix_fun_usd.restype = None
real_gen_matrix_fun_usd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    real_gen_matrix_fun_usd_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, imnorm.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_sqrt = utils._EngineState._get_symbol('f01enf')
real_gen_matrix_sqrt.restype = None
real_gen_matrix_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_tri_matrix_sqrt = utils._EngineState._get_symbol('f01epf')
real_tri_matrix_sqrt.restype = None
real_tri_matrix_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_pow = utils._EngineState._get_symbol('f01eqf')
real_gen_matrix_pow.restype = None
real_gen_matrix_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_exp = utils._EngineState._get_symbol('f01fcf')
complex_gen_matrix_exp.restype = None
complex_gen_matrix_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_herm_matrix_exp = utils._EngineState._get_symbol('f01fdf')
complex_herm_matrix_exp.restype = None
complex_herm_matrix_exp.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

complex_herm_matrix_fun_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, x[n].
    utils._EngineFloat64ArrayType.c_type, # Output, fx[n].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
complex_herm_matrix_fun = utils._EngineState._get_symbol('f01fff')
complex_herm_matrix_fun.restype = None
complex_herm_matrix_fun.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    complex_herm_matrix_fun_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)

complex_gen_matrix_log = utils._EngineState._get_symbol('f01fjf')
complex_gen_matrix_log.restype = None
complex_gen_matrix_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_fun_std = utils._EngineState._get_symbol('f01fkf')
complex_gen_matrix_fun_std.restype = None
complex_gen_matrix_fun_std.argtypes = (
    utils._BYREF_STRING, # Input, fun(len=*).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fun.
)

complex_gen_matrix_fun_num_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
complex_gen_matrix_fun_num = utils._EngineState._get_symbol('f01flf')
complex_gen_matrix_fun_num.restype = None
complex_gen_matrix_fun_num.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    complex_gen_matrix_fun_num_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_fun_usd_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
complex_gen_matrix_fun_usd = utils._EngineState._get_symbol('f01fmf')
complex_gen_matrix_fun_usd.restype = None
complex_gen_matrix_fun_usd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    complex_gen_matrix_fun_usd_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_sqrt = utils._EngineState._get_symbol('f01fnf')
complex_gen_matrix_sqrt.restype = None
complex_gen_matrix_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_tri_matrix_sqrt = utils._EngineState._get_symbol('f01fpf')
complex_tri_matrix_sqrt.restype = None
complex_tri_matrix_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_pow = utils._EngineState._get_symbol('f01fqf')
complex_gen_matrix_pow.restype = None
complex_gen_matrix_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_actexp = utils._EngineState._get_symbol('f01gaf')
real_gen_matrix_actexp.restype = None
real_gen_matrix_actexp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_actexp_rcomm = utils._EngineState._get_symbol('f01gbf')
real_gen_matrix_actexp_rcomm.restype = None
real_gen_matrix_actexp_rcomm.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_FLOAT64, # Input, t.
    utils._BYREF_FLOAT64, # Input, tr.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b2[ldb2, *].
    utils._BYREF_INT, # Input, ldb2.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[ldy, *].
    utils._BYREF_INT, # Input, ldy.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, p[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, r[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, z[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[n*m+3*n+12].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[2*n+40].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_actexp = utils._EngineState._get_symbol('f01haf')
complex_gen_matrix_actexp.restype = None
complex_gen_matrix_actexp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, t.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_actexp_rcomm = utils._EngineState._get_symbol('f01hbf')
complex_gen_matrix_actexp_rcomm.restype = None
complex_gen_matrix_actexp_rcomm.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_COMPLEX128, # Input, t.
    utils._BYREF_COMPLEX128, # Input, tr.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b2[ldb2, *].
    utils._BYREF_INT, # Input, ldb2.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, y[ldy, *].
    utils._BYREF_INT, # Input, ldy.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, p[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, r[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, z[n].
    utils._EngineComplex128ArrayType.c_type, # Input/Output, ccomm[n*(m+2)].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[3*n+14].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[2*n+40].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_std = utils._EngineState._get_symbol('f01jaf')
real_gen_matrix_cond_std.restype = None
real_gen_matrix_cond_std.argtypes = (
    utils._BYREF_STRING, # Input, fun(len=*).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fun.
)

real_gen_matrix_cond_num_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_matrix_cond_num = utils._EngineState._get_symbol('f01jbf')
real_gen_matrix_cond_num.restype = None
real_gen_matrix_cond_num.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    real_gen_matrix_cond_num_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_usd_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
real_gen_matrix_cond_usd = utils._EngineState._get_symbol('f01jcf')
real_gen_matrix_cond_usd.restype = None
real_gen_matrix_cond_usd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    real_gen_matrix_cond_usd_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_sqrt = utils._EngineState._get_symbol('f01jdf')
real_gen_matrix_cond_sqrt.restype = None
real_gen_matrix_cond_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, alpha.
    utils._BYREF_FLOAT64, # Output, condsa.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_pow = utils._EngineState._get_symbol('f01jef')
real_gen_matrix_cond_pow.restype = None
real_gen_matrix_cond_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_FLOAT64, # Output, condpa.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_frcht_pow = utils._EngineState._get_symbol('f01jff')
real_gen_matrix_frcht_pow.restype = None
real_gen_matrix_frcht_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_exp = utils._EngineState._get_symbol('f01jgf')
real_gen_matrix_cond_exp.restype = None
real_gen_matrix_cond_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, condea.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_frcht_exp = utils._EngineState._get_symbol('f01jhf')
real_gen_matrix_frcht_exp.restype = None
real_gen_matrix_frcht_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_cond_log = utils._EngineState._get_symbol('f01jjf')
real_gen_matrix_cond_log.restype = None
real_gen_matrix_cond_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, condla.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_matrix_frcht_log = utils._EngineState._get_symbol('f01jkf')
real_gen_matrix_frcht_log.restype = None
real_gen_matrix_frcht_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_std = utils._EngineState._get_symbol('f01kaf')
complex_gen_matrix_cond_std.restype = None
complex_gen_matrix_cond_std.argtypes = (
    utils._BYREF_STRING, # Input, fun(len=*).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of fun.
)

complex_gen_matrix_cond_num_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
complex_gen_matrix_cond_num = utils._EngineState._get_symbol('f01kbf')
complex_gen_matrix_cond_num.restype = None
complex_gen_matrix_cond_num.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    complex_gen_matrix_cond_num_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_usd_f = utils._EngineState._sys_functype(
    None,
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input/Output, iflag.
    utils._BYREF_INT, # Input, nz.
    utils._EngineComplex128ArrayType.c_type, # Input, z[nz].
    utils._EngineComplex128ArrayType.c_type, # Output, fz[nz].
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
)
complex_gen_matrix_cond_usd = utils._EngineState._get_symbol('f01kcf')
complex_gen_matrix_cond_usd.restype = None
complex_gen_matrix_cond_usd.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    complex_gen_matrix_cond_usd_f,
    utils._EngineIntArrayType.c_type, # Input/Output, iuser[*].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ruser[*].
    utils._BYREF_INT, # Output, iflag.
    utils._BYREF_FLOAT64, # Output, conda.
    utils._BYREF_FLOAT64, # Output, norma.
    utils._BYREF_FLOAT64, # Output, normfa.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_sqrt = utils._EngineState._get_symbol('f01kdf')
complex_gen_matrix_cond_sqrt.restype = None
complex_gen_matrix_cond_sqrt.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, alpha.
    utils._BYREF_FLOAT64, # Output, condsa.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_pow = utils._EngineState._get_symbol('f01kef')
complex_gen_matrix_cond_pow.restype = None
complex_gen_matrix_cond_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_FLOAT64, # Output, condpa.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_frcht_pow = utils._EngineState._get_symbol('f01kff')
complex_gen_matrix_frcht_pow.restype = None
complex_gen_matrix_frcht_pow.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_FLOAT64, # Input, p.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_exp = utils._EngineState._get_symbol('f01kgf')
complex_gen_matrix_cond_exp.restype = None
complex_gen_matrix_cond_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, condea.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_frcht_exp = utils._EngineState._get_symbol('f01khf')
complex_gen_matrix_frcht_exp.restype = None
complex_gen_matrix_frcht_exp.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_cond_log = utils._EngineState._get_symbol('f01kjf')
complex_gen_matrix_cond_log.restype = None
complex_gen_matrix_cond_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_FLOAT64, # Output, condla.
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_matrix_frcht_log = utils._EngineState._get_symbol('f01kkf')
complex_gen_matrix_frcht_log.restype = None
complex_gen_matrix_frcht_log.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, e[lde, *].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_tridiag_lu = utils._EngineState._get_symbol('f01lef')
real_gen_tridiag_lu.restype = None
real_gen_tridiag_lu.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[n].
    utils._BYREF_FLOAT64, # Input, lambda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[n].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, c[n].
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._EngineIntArrayType.c_type, # Output, ipiv[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_blkdiag_lu = utils._EngineState._get_symbol('f01lhf')
real_gen_blkdiag_lu.restype = None
real_gen_blkdiag_lu.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nbloks.
    utils._EngineIntArrayType.c_type, # Input, blkstr[3, nbloks].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lena].
    utils._BYREF_INT, # Input, lena.
    utils._EngineIntArrayType.c_type, # Output, pivot[n].
    utils._BYREF_FLOAT64, # Input/Output, tol.
    utils._BYREF_INT, # Output, kpivot.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_vband_posdef_fac = utils._EngineState._get_symbol('f01mcf')
real_vband_posdef_fac.restype = None
real_vband_posdef_fac.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lal].
    utils._BYREF_INT, # Input, lal.
    utils._EngineIntArrayType.c_type, # Input/Output, nrow[n].
    utils._EngineFloat64ArrayType.c_type, # Output, al[lal].
    utils._EngineFloat64ArrayType.c_type, # Output, d[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_trapez_rq = utils._EngineState._get_symbol('f01qgf')
real_trapez_rq.restype = None
real_trapez_rq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, zeta[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_rq = utils._EngineState._get_symbol('f01qjf')
real_gen_rq.restype = None
real_gen_rq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, zeta[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

real_gen_rq_formq = utils._EngineState._get_symbol('f01qkf')
real_gen_rq_formq.restype = None
real_gen_rq_formq.argtypes = (
    utils._BYREF_STRING, # Input, wheret(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrowp.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input, zeta[*].
    utils._EngineFloat64ArrayType.c_type, # Workspace, work[max(m-1, nrowp-m, 1)].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of wheret.
)

complex_trapez_rq = utils._EngineState._get_symbol('f01rgf')
complex_trapez_rq.restype = None
complex_trapez_rq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, theta[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_rq = utils._EngineState._get_symbol('f01rjf')
complex_gen_rq.restype = None
complex_gen_rq.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, theta[m].
    utils._BYREF_INT, # Input/Output, ifail.
)

complex_gen_rq_formq = utils._EngineState._get_symbol('f01rkf')
complex_gen_rq_formq.restype = None
complex_gen_rq_formq.argtypes = (
    utils._BYREF_STRING, # Input, wheret(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, nrowp.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input, theta[*].
    utils._EngineComplex128ArrayType.c_type, # Workspace, work[max(m-1, nrowp-m, 1)].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of wheret.
)

real_nmf = utils._EngineState._get_symbol('f01saf')
real_nmf.restype = None
real_nmf.argtypes = (
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, w[ldw, *].
    utils._BYREF_INT, # Input, ldw.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._BYREF_INT, # Input, seed.
    utils._BYREF_FLOAT64, # Input, errtol.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_INT, # Input/Output, ifail.
)

real_nmf_rcomm = utils._EngineState._get_symbol('f01sbf')
real_nmf_rcomm.restype = None
real_nmf_rcomm.argtypes = (
    utils._BYREF_INT, # Input/Output, irevcm.
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, w[ldw, *].
    utils._BYREF_INT, # Input, ldw.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, h[ldh, *].
    utils._BYREF_INT, # Input, ldh.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, ht[ldht, *].
    utils._BYREF_INT, # Input, ldht.
    utils._BYREF_INT, # Input, seed.
    utils._BYREF_FLOAT64, # Input, errtol.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, comm[(2*m+n)*k+3].
    utils._EngineIntArrayType.c_type, # Input/Output, icomm[9].
    utils._BYREF_INT, # Input/Output, ifail.
)

dtrttp = utils._EngineState._get_symbol('dtrttp')
dtrttp.restype = None
dtrttp.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, ap[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vaf = utils._EngineState._get_symbol('f01vaf')
f01vaf.restype = dtrttp.restype
f01vaf.argtypes = dtrttp.argtypes

ztrttp = utils._EngineState._get_symbol('ztrttp')
ztrttp.restype = None
ztrttp.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, ap[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vbf = utils._EngineState._get_symbol('f01vbf')
f01vbf.restype = ztrttp.restype
f01vbf.argtypes = ztrttp.argtypes

dtpttr = utils._EngineState._get_symbol('dtpttr')
dtpttr.restype = None
dtpttr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vcf = utils._EngineState._get_symbol('f01vcf')
f01vcf.restype = dtpttr.restype
f01vcf.argtypes = dtpttr.argtypes

ztpttr = utils._EngineState._get_symbol('ztpttr')
ztpttr.restype = None
ztpttr.argtypes = (
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[n*(n+1)/2].
    utils._EngineComplex128ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vdf = utils._EngineState._get_symbol('f01vdf')
f01vdf.restype = ztpttr.restype
f01vdf.argtypes = ztpttr.argtypes

dtrttf = utils._EngineState._get_symbol('dtrttf')
dtrttf.restype = None
dtrttf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vef = utils._EngineState._get_symbol('f01vef')
f01vef.restype = dtrttf.restype
f01vef.argtypes = dtrttf.argtypes

ztrttf = utils._EngineState._get_symbol('ztrttf')
ztrttf.restype = None
ztrttf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vff = utils._EngineState._get_symbol('f01vff')
f01vff.restype = ztrttf.restype
f01vff.argtypes = ztrttf.argtypes

dtfttr = utils._EngineState._get_symbol('dtfttr')
dtfttr.restype = None
dtfttr.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vgf = utils._EngineState._get_symbol('f01vgf')
f01vgf.restype = dtfttr.restype
f01vgf.argtypes = dtfttr.argtypes

ztfttr = utils._EngineState._get_symbol('ztfttr')
ztfttr.restype = None
ztfttr.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineComplex128ArrayType.c_type, # Output, a[lda, *].
    utils._BYREF_INT, # Input, lda.
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vhf = utils._EngineState._get_symbol('f01vhf')
f01vhf.restype = ztfttr.restype
f01vhf.argtypes = ztfttr.argtypes

dtpttf = utils._EngineState._get_symbol('dtpttf')
dtpttf.restype = None
dtpttf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ap[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vjf = utils._EngineState._get_symbol('f01vjf')
f01vjf.restype = dtpttf.restype
f01vjf.argtypes = dtpttf.argtypes

ztpttf = utils._EngineState._get_symbol('ztpttf')
ztpttf.restype = None
ztpttf.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ap[n*(n+1)/2].
    utils._EngineComplex128ArrayType.c_type, # Output, ar[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vkf = utils._EngineState._get_symbol('f01vkf')
f01vkf.restype = ztpttf.restype
f01vkf.argtypes = ztpttf.argtypes

dtfttp = utils._EngineState._get_symbol('dtfttp')
dtfttp.restype = None
dtfttp.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, ap[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vlf = utils._EngineState._get_symbol('f01vlf')
f01vlf.restype = dtfttp.restype
f01vlf.argtypes = dtfttp.argtypes

ztfttp = utils._EngineState._get_symbol('ztfttp')
ztfttp.restype = None
ztfttp.argtypes = (
    utils._BYREF_STRING, # Input, transr(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input, ar[n*(n+1)/2].
    utils._EngineComplex128ArrayType.c_type, # Output, ap[n*(n+1)/2].
    utils._BYREF_INT, # Output, info.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of transr.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
)
f01vmf = utils._EngineState._get_symbol('f01vmf')
f01vmf.restype = ztfttp.restype
f01vmf.argtypes = ztfttp.argtypes

real_tri_pack = utils._EngineState._get_symbol('f01zaf')
real_tri_pack.restype = None
real_tri_pack.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[(n*(n+1))/2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

complex_tri_pack = utils._EngineState._get_symbol('f01zbf')
complex_tri_pack.restype = None
complex_tri_pack.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_STRING, # Input, uplo(len=1).
    utils._BYREF_STRING, # Input, diag(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[(n*(n+1))/2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of uplo.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of diag.
)

real_band_pack = utils._EngineState._get_symbol('f01zcf')
real_band_pack.restype = None
real_band_pack.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)

complex_band_pack = utils._EngineState._get_symbol('f01zdf')
complex_band_pack.restype = None
complex_band_pack.argtypes = (
    utils._BYREF_STRING, # Input, job(len=1).
    utils._BYREF_INT, # Input, m.
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, kl.
    utils._BYREF_INT, # Input, ku.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, a[lda, n].
    utils._BYREF_INT, # Input, lda.
    utils._EngineComplex128ArrayType.c_type, # Input/Output, b[ldb, *].
    utils._BYREF_INT, # Input, ldb.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of job.
)
