# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `mv` Chapter.
"""

# NAG Copyright 2017-2019.

from ..base import utils

prin_comp = utils._EngineState._get_symbol('g03aaf')
prin_comp.restype = None
prin_comp.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_STRING, # Input, std(len=1).
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[m].
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._BYREF_INT, # Input, nvar.
    utils._EngineFloat64ArrayType.c_type, # Output, e[lde, 6].
    utils._BYREF_INT, # Input, lde.
    utils._EngineFloat64ArrayType.c_type, # Output, p[ldp, nvar].
    utils._BYREF_INT, # Input, ldp.
    utils._EngineFloat64ArrayType.c_type, # Output, v[ldv, nvar].
    utils._BYREF_INT, # Input, ldv.
    utils._EngineFloat64ArrayType.c_type, # Input, wk[1].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of std.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

canon_var = utils._EngineState._get_symbol('g03acf')
canon_var.restype = None
canon_var.argtypes = (
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._BYREF_INT, # Input, nx.
    utils._EngineIntArrayType.c_type, # Input, ing[n].
    utils._BYREF_INT, # Input, ng.
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineIntArrayType.c_type, # Output, nig[ng].
    utils._EngineFloat64ArrayType.c_type, # Output, cvm[ldcvm, nx].
    utils._BYREF_INT, # Input, ldcvm.
    utils._EngineFloat64ArrayType.c_type, # Output, e[lde, 6].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Output, ncv.
    utils._EngineFloat64ArrayType.c_type, # Output, cvx[ldcvx, ng-1].
    utils._BYREF_INT, # Input, ldcvx.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_INT, # Output, irankx.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[iwk].
    utils._BYREF_INT, # Input, iwk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

canon_corr = utils._EngineState._get_symbol('g03adf')
canon_corr.restype = None
canon_corr.argtypes = (
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, z[ldz, m].
    utils._BYREF_INT, # Input, ldz.
    utils._EngineIntArrayType.c_type, # Input, isz[m].
    utils._BYREF_INT, # Input, nx.
    utils._BYREF_INT, # Input, ny.
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[lde, 6].
    utils._BYREF_INT, # Input, lde.
    utils._BYREF_INT, # Output, ncv.
    utils._EngineFloat64ArrayType.c_type, # Output, cvx[ldcvx, mcv].
    utils._BYREF_INT, # Input, ldcvx.
    utils._BYREF_INT, # Input, mcv.
    utils._EngineFloat64ArrayType.c_type, # Output, cvy[ldcvy, mcv].
    utils._BYREF_INT, # Input, ldcvy.
    utils._BYREF_FLOAT64, # Input, tol.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[iwk].
    utils._BYREF_INT, # Input, iwk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

rot_orthomax = utils._EngineState._get_symbol('g03baf')
rot_orthomax.restype = None
rot_orthomax.argtypes = (
    utils._BYREF_STRING, # Input, stand(len=1).
    utils._BYREF_FLOAT64, # Input, g.
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, fl[ldfl, k].
    utils._BYREF_INT, # Input, ldfl.
    utils._EngineFloat64ArrayType.c_type, # Output, flr[ldfl, k].
    utils._EngineFloat64ArrayType.c_type, # Output, r[ldr, k].
    utils._BYREF_INT, # Input, ldr.
    utils._BYREF_FLOAT64, # Input, acc.
    utils._BYREF_INT, # Input, maxit.
    utils._BYREF_INT, # Output, iter.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2*nvar+k*k+5*(k-1)].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of stand.
)

rot_procrustes = utils._EngineState._get_symbol('g03bcf')
rot_procrustes.restype = None
rot_procrustes.argtypes = (
    utils._BYREF_STRING, # Input, stand(len=1).
    utils._BYREF_STRING, # Input, pscale(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, y[ldy, m].
    utils._BYREF_INT, # Input, ldy.
    utils._EngineFloat64ArrayType.c_type, # Output, yhat[ldy, m].
    utils._EngineFloat64ArrayType.c_type, # Output, r[ldr, m].
    utils._BYREF_INT, # Input, ldr.
    utils._BYREF_FLOAT64, # Output, alpha.
    utils._BYREF_FLOAT64, # Output, rss.
    utils._EngineFloat64ArrayType.c_type, # Output, res[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[m*m+7*m].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of stand.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of pscale.
)

rot_promax = utils._EngineState._get_symbol('g03bdf')
rot_promax.restype = None
rot_promax.argtypes = (
    utils._BYREF_STRING, # Input, stand(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Input, ro[ldro, m].
    utils._BYREF_INT, # Input, ldro.
    utils._BYREF_FLOAT64, # Input, power.
    utils._EngineFloat64ArrayType.c_type, # Output, fp[ldfp, m].
    utils._BYREF_INT, # Input, ldfp.
    utils._EngineFloat64ArrayType.c_type, # Output, r[ldr, m].
    utils._BYREF_INT, # Input, ldr.
    utils._EngineFloat64ArrayType.c_type, # Output, phi[ldphi, m].
    utils._BYREF_INT, # Input, ldphi.
    utils._EngineFloat64ArrayType.c_type, # Output, fs[ldfs, m].
    utils._BYREF_INT, # Input, ldfs.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of stand.
)

factor = utils._EngineState._get_symbol('g03caf')
factor.restype = None
factor.argtypes = (
    utils._BYREF_STRING, # Input, matrix(len=1).
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_INT, # Input, nvar.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._BYREF_INT, # Input, nfac.
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineFloat64ArrayType.c_type, # Output, e[nvar].
    utils._EngineFloat64ArrayType.c_type, # Output, stat[4].
    utils._EngineFloat64ArrayType.c_type, # Output, com[nvar].
    utils._EngineFloat64ArrayType.c_type, # Output, psi[nvar].
    utils._EngineFloat64ArrayType.c_type, # Output, res[nvar*(nvar-1)/2].
    utils._EngineFloat64ArrayType.c_type, # Output, fl[ldfl, nfac].
    utils._BYREF_INT, # Input, ldfl.
    utils._EngineIntArrayType.c_type, # Input, iop[5].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[4*nvar+2].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[lwk].
    utils._BYREF_INT, # Input, lwk.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of matrix.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

factor_score = utils._EngineState._get_symbol('g03ccf')
factor_score.restype = None
factor_score.argtypes = (
    utils._BYREF_STRING, # Input, method(len=1).
    utils._BYREF_STRING, # Input, rotate(len=1).
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, nfac.
    utils._EngineFloat64ArrayType.c_type, # Input, fl[ldfl, nfac].
    utils._BYREF_INT, # Input, ldfl.
    utils._EngineFloat64ArrayType.c_type, # Input, psi[nvar].
    utils._EngineFloat64ArrayType.c_type, # Input, e[nvar].
    utils._EngineFloat64ArrayType.c_type, # Input, r[ldr, *].
    utils._BYREF_INT, # Input, ldr.
    utils._EngineFloat64ArrayType.c_type, # Output, fs[ldfs, nfac].
    utils._BYREF_INT, # Input, ldfs.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[nvar].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of method.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of rotate.
)

discrim = utils._EngineState._get_symbol('g03daf')
discrim.restype = None
discrim.argtypes = (
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._BYREF_INT, # Input, nvar.
    utils._EngineIntArrayType.c_type, # Input, ing[n].
    utils._BYREF_INT, # Input, ng.
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineIntArrayType.c_type, # Output, nig[ng].
    utils._EngineFloat64ArrayType.c_type, # Output, gmn[ldgmn, nvar].
    utils._BYREF_INT, # Input, ldgmn.
    utils._EngineFloat64ArrayType.c_type, # Output, det[ng].
    utils._EngineFloat64ArrayType.c_type, # Output, gc[(ng+1)*nvar*(nvar+1)/2].
    utils._BYREF_FLOAT64, # Output, stat.
    utils._BYREF_FLOAT64, # Output, df.
    utils._BYREF_FLOAT64, # Output, sig.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[n*(nvar+1)].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[ng].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

discrim_mahal = utils._EngineState._get_symbol('g03dbf')
discrim_mahal.restype = None
discrim_mahal.argtypes = (
    utils._BYREF_STRING, # Input, equal(len=1).
    utils._BYREF_STRING, # Input, mode(len=1).
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, ng.
    utils._EngineFloat64ArrayType.c_type, # Input, gmn[ldgmn, nvar].
    utils._BYREF_INT, # Input, ldgmn.
    utils._EngineFloat64ArrayType.c_type, # Input, gc[(ng+1)*nvar*(nvar+1)/2].
    utils._BYREF_INT, # Input, nobs.
    utils._BYREF_INT, # Input, m.
    utils._EngineIntArrayType.c_type, # Input, isx[*].
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, *].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, d[ldd, ng].
    utils._BYREF_INT, # Input, ldd.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2*nvar].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equal.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of mode.
)

discrim_group = utils._EngineState._get_symbol('g03dcf')
discrim_group.restype = None
discrim_group.argtypes = (
    utils._BYREF_STRING, # Input, typ(len=1).
    utils._BYREF_STRING, # Input, equal(len=1).
    utils._BYREF_STRING, # Input, priors(len=1).
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, ng.
    utils._EngineIntArrayType.c_type, # Input, nig[ng].
    utils._EngineFloat64ArrayType.c_type, # Input, gmn[ldgmn, nvar].
    utils._BYREF_INT, # Input, ldgmn.
    utils._EngineFloat64ArrayType.c_type, # Input, gc[(ng+1)*nvar*(nvar+1)/2].
    utils._EngineFloat64ArrayType.c_type, # Input, det[ng].
    utils._BYREF_INT, # Input, nobs.
    utils._BYREF_INT, # Input, m.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, prior[ng].
    utils._EngineFloat64ArrayType.c_type, # Output, p[ldp, ng].
    utils._BYREF_INT, # Input, ldp.
    utils._EngineIntArrayType.c_type, # Output, iag[nobs].
    utils._BYREF_LOGICAL, # Input, atiq.
    utils._EngineFloat64ArrayType.c_type, # Output, ati[ldp, *].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[2*nvar].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of typ.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of equal.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of priors.
)

distance_mat = utils._EngineState._get_symbol('g03eaf')
distance_mat.restype = None
distance_mat.argtypes = (
    utils._BYREF_STRING, # Input, update(len=1).
    utils._BYREF_STRING, # Input, dist(len=1).
    utils._BYREF_STRING, # Input, scal(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, s[m].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[n*(n-1)/2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of update.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of dist.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of scal.
)

cluster_hier = utils._EngineState._get_symbol('g03ecf')
cluster_hier.restype = None
cluster_hier.argtypes = (
    utils._BYREF_INT, # Input, method.
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, d[n*(n-1)/2].
    utils._EngineIntArrayType.c_type, # Output, ilc[n-1].
    utils._EngineIntArrayType.c_type, # Output, iuc[n-1].
    utils._EngineFloat64ArrayType.c_type, # Output, cd[n-1].
    utils._EngineIntArrayType.c_type, # Output, iord[n].
    utils._EngineFloat64ArrayType.c_type, # Output, dord[n].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[2*n].
    utils._BYREF_INT, # Input/Output, ifail.
)

cluster_kmeans = utils._EngineState._get_symbol('g03eff')
cluster_kmeans.restype = None
cluster_kmeans.argtypes = (
    utils._BYREF_STRING, # Input, weight(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, k.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, cmeans[ldc, nvar].
    utils._BYREF_INT, # Input, ldc.
    utils._EngineFloat64ArrayType.c_type, # Input, wt[*].
    utils._EngineIntArrayType.c_type, # Output, inc[n].
    utils._EngineIntArrayType.c_type, # Output, nic[k].
    utils._EngineFloat64ArrayType.c_type, # Output, css[k].
    utils._EngineFloat64ArrayType.c_type, # Output, csw[k].
    utils._BYREF_INT, # Input, maxit.
    utils._EngineIntArrayType.c_type, # Workspace, iwk[n+3*k].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[n+2*k].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of weight.
)

cluster_hier_dendrogram = utils._EngineState._get_symbol('g03ehf')
cluster_hier_dendrogram.restype = None
cluster_hier_dendrogram.argtypes = (
    utils._BYREF_STRING, # Input, orient(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, dord[n].
    utils._BYREF_FLOAT64, # Input, dmin.
    utils._BYREF_FLOAT64, # Input, dstep.
    utils._BYREF_INT, # Input, nsym.
    utils._EngineCharArrayType.c_type, # Output, c(len=*)[lenc].
    utils._BYREF_INT, # Input, lenc.
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of orient.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of c.
)

cluster_hier_indicator = utils._EngineState._get_symbol('g03ejf')
cluster_hier_indicator.restype = None
cluster_hier_indicator.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, cd[n-1].
    utils._EngineIntArrayType.c_type, # Input, iord[n].
    utils._EngineFloat64ArrayType.c_type, # Input, dord[n].
    utils._BYREF_INT, # Input/Output, k.
    utils._BYREF_FLOAT64, # Input/Output, dlevel.
    utils._EngineIntArrayType.c_type, # Output, ic[n].
    utils._BYREF_INT, # Input/Output, ifail.
)

multidimscal_metric = utils._EngineState._get_symbol('g03faf')
multidimscal_metric.restype = None
multidimscal_metric.argtypes = (
    utils._BYREF_STRING, # Input, roots(len=1).
    utils._BYREF_INT, # Input, n.
    utils._EngineFloat64ArrayType.c_type, # Input, d[n*(n-1)/2].
    utils._BYREF_INT, # Input, ndim.
    utils._EngineFloat64ArrayType.c_type, # Output, x[ldx, ndim].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineFloat64ArrayType.c_type, # Output, eval[n].
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[n*(n+17)/2-1].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[5*n].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of roots.
)

multidimscal_ordinal = utils._EngineState._get_symbol('g03fcf')
multidimscal_ordinal.restype = None
multidimscal_ordinal.argtypes = (
    utils._BYREF_STRING, # Input, typ(len=1).
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, ndim.
    utils._EngineFloat64ArrayType.c_type, # Input, d[n*(n-1)/2].
    utils._EngineFloat64ArrayType.c_type, # Input/Output, x[ldx, ndim].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_FLOAT64, # Output, stress.
    utils._EngineFloat64ArrayType.c_type, # Output, dfit[2*n*(n-1)].
    utils._BYREF_INT, # Input, iter.
    utils._BYREF_INT, # Input, iopt.
    utils._EngineFloat64ArrayType.c_type, # Workspace, wk[15*n*ndim].
    utils._EngineIntArrayType.c_type, # Workspace, iwk[n*(n-1)/2+n*ndim+5].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of typ.
)

gaussian_mixture = utils._EngineState._get_symbol('g03gaf')
gaussian_mixture.restype = None
gaussian_mixture.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._BYREF_INT, # Input, nvar.
    utils._BYREF_INT, # Input, ng.
    utils._BYREF_INT, # Input, popt.
    utils._EngineFloat64ArrayType.c_type, # Input/Output, prob[lprob, ng].
    utils._BYREF_INT, # Input, lprob.
    utils._BYREF_INT, # Input/Output, niter.
    utils._BYREF_INT, # Input, riter.
    utils._EngineFloat64ArrayType.c_type, # Output, w[ng].
    utils._EngineFloat64ArrayType.c_type, # Output, g[nvar, ng].
    utils._BYREF_INT, # Input, sopt.
    utils._EngineFloat64ArrayType.c_type, # Output, s[lds, sds, *].
    utils._BYREF_INT, # Input, lds.
    utils._BYREF_INT, # Input, sds.
    utils._EngineFloat64ArrayType.c_type, # Output, f[n, ng].
    utils._BYREF_FLOAT64, # Input, tol.
    utils._BYREF_FLOAT64, # Output, loglik.
    utils._BYREF_INT, # Input/Output, ifail.
)

z_scores = utils._EngineState._get_symbol('g03zaf')
z_scores.restype = None
z_scores.argtypes = (
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m.
    utils._EngineFloat64ArrayType.c_type, # Input, x[ldx, m].
    utils._BYREF_INT, # Input, ldx.
    utils._BYREF_INT, # Input, nvar.
    utils._EngineIntArrayType.c_type, # Input, isx[m].
    utils._EngineFloat64ArrayType.c_type, # Input, s[m].
    utils._EngineFloat64ArrayType.c_type, # Input, e[m].
    utils._EngineFloat64ArrayType.c_type, # Output, z[ldz, nvar].
    utils._BYREF_INT, # Input, ldz.
    utils._BYREF_INT, # Input/Output, ifail.
)
