# -*- coding: utf-8 -*-
# pylint: disable=invalid-name,line-too-long,protected-access,too-many-locals
# pylint: disable=too-many-lines
"""
Primitive ``ctypes`` prototypes for the NAG Library `sort` Chapter.
"""

# NAG Copyright 2017-2019.

from ..base import utils

realvec_sort = utils._EngineState._get_symbol('m01caf')
realvec_sort.restype = None
realvec_sort.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

intvec_sort = utils._EngineState._get_symbol('m01cbf')
intvec_sort.restype = None
intvec_sort.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, iv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

charvec_sort = utils._EngineState._get_symbol('m01ccf')
charvec_sort.restype = None
charvec_sort.argtypes = (
    utils._EngineCharArrayType.c_type, # Input/Output, ch(len=*)[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, l1.
    utils._BYREF_INT, # Input, l2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of ch.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

realvec_rank = utils._EngineState._get_symbol('m01daf')
realvec_rank.restype = None
realvec_rank.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, rv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

intvec_rank = utils._EngineState._get_symbol('m01dbf')
intvec_rank.restype = None
intvec_rank.argtypes = (
    utils._EngineIntArrayType.c_type, # Input, iv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

charvec_rank = utils._EngineState._get_symbol('m01dcf')
charvec_rank.restype = None
charvec_rank.argtypes = (
    utils._EngineCharArrayType.c_type, # Input, ch(len=*)[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, l1.
    utils._BYREF_INT, # Input, l2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of ch.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

realmat_rank_rows = utils._EngineState._get_symbol('m01def')
realmat_rank_rows.restype = None
realmat_rank_rows.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, rm[ldm, n2].
    utils._BYREF_INT, # Input, ldm.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

intmat_rank_rows = utils._EngineState._get_symbol('m01dff')
intmat_rank_rows.restype = None
intmat_rank_rows.argtypes = (
    utils._EngineIntArrayType.c_type, # Input, im[ldm, n2].
    utils._BYREF_INT, # Input, ldm.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

realmat_rank_columns = utils._EngineState._get_symbol('m01djf')
realmat_rank_columns.restype = None
realmat_rank_columns.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input, rm[ldm, n2].
    utils._BYREF_INT, # Input, ldm.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[n2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

intmat_rank_columns = utils._EngineState._get_symbol('m01dkf')
intmat_rank_columns.restype = None
intmat_rank_columns.argtypes = (
    utils._EngineIntArrayType.c_type, # Input, im[ldm, n2].
    utils._BYREF_INT, # Input, ldm.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, n1.
    utils._BYREF_INT, # Input, n2.
    utils._BYREF_STRING, # Input, order(len=1).
    utils._EngineIntArrayType.c_type, # Output, irank[n2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of order.
)

arbitrary_rank_compar = utils._EngineState._sys_functype(
    utils._EngineLogicalScalarType.c_type,
    utils._BYREF_INT, # Input, i.
    utils._BYREF_INT, # Input, j.
)
arbitrary_rank = utils._EngineState._get_symbol('m01dzf')
arbitrary_rank.restype = None
arbitrary_rank.argtypes = (
    arbitrary_rank_compar,
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
)

realvec_rank_rearrange = utils._EngineState._get_symbol('m01eaf')
realvec_rank_rearrange.restype = None
realvec_rank_rearrange.argtypes = (
    utils._EngineFloat64ArrayType.c_type, # Input/Output, rv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Input/Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
)

intvec_rank_rearrange = utils._EngineState._get_symbol('m01ebf')
intvec_rank_rearrange.restype = None
intvec_rank_rearrange.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, iv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Input/Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
)

charvec_rank_rearrange = utils._EngineState._get_symbol('m01ecf')
charvec_rank_rearrange.restype = None
charvec_rank_rearrange.argtypes = (
    utils._EngineCharArrayType.c_type, # Input/Output, ch(len=*)[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Input/Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of ch.
)

cmplxvec_rank_rearrange = utils._EngineState._get_symbol('m01edf')
cmplxvec_rank_rearrange.restype = None
cmplxvec_rank_rearrange.argtypes = (
    utils._EngineComplex128ArrayType.c_type, # Input/Output, cv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Input/Output, irank[m2].
    utils._BYREF_INT, # Input/Output, ifail.
)

realvec_search = utils._EngineState._get_symbol('m01naf')
realvec_search.restype = utils._EngineIntScalarType.c_type
realvec_search.argtypes = (
    utils._BYREF_LOGICAL, # Input, valid.
    utils._EngineFloat64ArrayType.c_type, # Input, rv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_FLOAT64, # Input, item.
    utils._BYREF_INT, # Input/Output, ifail.
)

intvec_search = utils._EngineState._get_symbol('m01nbf')
intvec_search.restype = utils._EngineIntScalarType.c_type
intvec_search.argtypes = (
    utils._BYREF_LOGICAL, # Input, valid.
    utils._EngineIntArrayType.c_type, # Input, iv[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input, item.
    utils._BYREF_INT, # Input/Output, ifail.
)

charvec_search = utils._EngineState._get_symbol('m01ncf')
charvec_search.restype = utils._EngineIntScalarType.c_type
charvec_search.argtypes = (
    utils._BYREF_LOGICAL, # Input, valid.
    utils._EngineCharArrayType.c_type, # Input, ch(len=*)[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_STRING, # Input, item(len=*).
    utils._BYREF_INT, # Input/Output, ifail.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of ch.
    utils._EngineState._chrlen_ctype, # Input, hidden chrlen of item.
)

realvec_vec_search = utils._EngineState._get_symbol('m01ndf')
realvec_vec_search.restype = None
realvec_vec_search.argtypes = (
    utils._BYREF_LOGICAL, # Input, valid.
    utils._BYREF_INT, # Input, mode.
    utils._EngineFloat64ArrayType.c_type, # Input, rv[n].
    utils._BYREF_INT, # Input, n.
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineFloat64ArrayType.c_type, # Input, item[m].
    utils._BYREF_INT, # Input, m.
    utils._EngineIntArrayType.c_type, # Output, idx[m].
    utils._BYREF_FLOAT64, # Input/Output, h.
    utils._EngineIntArrayType.c_type, # Input/Output, k[lk].
    utils._BYREF_INT, # Input/Output, lk.
    utils._BYREF_INT, # Input/Output, ifail.
)

permute_invert = utils._EngineState._get_symbol('m01zaf')
permute_invert.restype = None
permute_invert.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, iperm[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input/Output, ifail.
)

permute_check = utils._EngineState._get_symbol('m01zbf')
permute_check.restype = None
permute_check.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, iperm[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._BYREF_INT, # Input/Output, ifail.
)

permute_decompose = utils._EngineState._get_symbol('m01zcf')
permute_decompose.restype = None
permute_decompose.argtypes = (
    utils._EngineIntArrayType.c_type, # Input/Output, iperm[m2].
    utils._BYREF_INT, # Input, m1.
    utils._BYREF_INT, # Input, m2.
    utils._EngineIntArrayType.c_type, # Output, icycl[m2].
    utils._BYREF_INT, # Input/Output, ifail.
)
