#!/usr/bin/env python
"``naginterfaces.library.zeros.poly_complex`` Python Example."

# NAG Copyright 2017-2018.

# pylint: disable=invalid-name

def main():
    """
    Example for :func:`naginterfaces.library.zeros.poly_complex`.

    Find all the roots of a complex polynomial equation.

    >>> main()
    naginterfaces.library.zeros.poly_complex Python Example Results.
    Roots of a complex polynomial equation.
    Computed roots:
    -24.328 +  -4.855j
      5.249 +  22.736j
     14.653 + -16.569j
     -0.007 +  -0.007j
      0.007 +   0.007j
    """

    from naginterfaces.library import zeros

    print('naginterfaces.library.zeros.poly_complex Python Example Results.')
    print('Roots of a complex polynomial equation.')

    coefs = [
        5.0 + 6.0j,
        30.0 + 20.0j,
        -0.2 + -6.0j,
        50.0 + 100000.0j,
        -2.0 + 40.0j,
        10.0 + 1.0j,
    ]

    z = zeros.poly_complex(coefs)

    print('Computed roots:')
    for z_val in z:
        print('{0.real:7.3f} + {0.imag:7.3f}j'.format(z_val))

if __name__ == '__main__':
    import doctest
    import sys
    sys.exit(
        doctest.testmod(
            None, verbose=True, report=False,
            optionflags=doctest.REPORT_NDIFF,
        ).failed
    )
