"""
Deprecated wrappers for the NAG C Library (Mark 26.0) a00 Chapter.

a00 - Library Identification.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/A00/a00conts.html

NAG Copyright 2017.
"""
from ctypes import c_char_p
from ctypes import c_ulong
from ctypes import POINTER
from .util import get_library
from .util import Nag_Boolean

_library_cl = get_library()

STRING = c_char_p

size_t = c_ulong
a00aac_ctypes = _library_cl.a00aac
a00aac_ctypes.restype = None
a00aac_ctypes.argtypes = []


def a00aac():
    """
    Library identification, details of implementation and mark.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/a00/a00aac.html
    """
    a00aac_ctypes()

a00acc_ctypes = _library_cl.a00acc
a00acc_ctypes.restype = Nag_Boolean
a00acc_ctypes.argtypes = []


def a00acc():
    """
    Check availability of a valid licence key.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/a00/a00acc.html
    """
    return_value = a00acc_ctypes()
    return return_value

a00adc_ctypes = _library_cl.a00adc
a00adc_ctypes.restype = None

a00adc_ctypes.argtypes = [STRING, STRING, STRING, STRING, STRING, STRING,
                          STRING, STRING, STRING, STRING, POINTER(Nag_Boolean)]


def a00adc(impl, prec, pcode, mkmaj, mkmin, hdware, opsys, ccomp, fcomp,
           vend, licval):
    """
    Library identification, details of implementation, major and minor
    marks.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/a00/a00adc.html
    """
    a00adc_ctypes(impl, prec, pcode, mkmaj, mkmin, hdware, opsys, ccomp,
                  fcomp, vend, licval)

nag_implementation_details = a00aac
nag_licence_query = a00acc
nag_implementation_separated_details = a00adc
__all__ = ['a00aac', 'a00acc', 'a00adc', 'nag_implementation_details',
           'nag_implementation_separated_details',
           'nag_licence_query']
