"""
Deprecated wrappers for the NAG C Library (Mark 26.0) d03 Chapter.

d03 - Partial Differential Equations.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/D03/d03conts.html

NAG Copyright 2017.
"""

from ctypes import c_double
from ctypes import POINTER
from ctypes import c_char_p
from .util import get_library
from .util import Integer
from .util import Nag_Comm
from .util import Nag_Boolean
from .util import NagError
from .util import NAG_D03PDC_PDEDEF
from .util import NAG_D03PDC_BNDARY
from .util import NAG_D03PDC_UINIT
from .util import NAG_D03PEC_PDEDEF
from .util import NAG_D03PEC_BNDARY
from .util import NAG_D03PFC_PDEDEF
from .util import NAG_D03PFC_NUMFLX
from .util import NAG_D03PFC_BNDARY
from .util import NAG_D03PHC_PDEDEF
from .util import NAG_D03PHC_BNDARY
from .util import NAG_D03PHC_ODEDEF
from .util import Nag_NormType
from .util import Nag_LinAlgOption
from .util import NAG_D03PJC_PDEDEF
from .util import NAG_D03PJC_BNDARY
from .util import NAG_D03PJC_ODEDEF
from .util import NAG_D03PJC_UVINIT
from .util import NAG_D03PKC_PDEDEF
from .util import NAG_D03PKC_BNDARY
from .util import NAG_D03PKC_ODEDEF
from .util import NAG_D03PLC_PDEDEF
from .util import NAG_D03PLC_NUMFLX
from .util import NAG_D03PLC_BNDARY
from .util import NAG_D03PLC_ODEDEF
from .util import NAG_D03PPC_PDEDEF
from .util import NAG_D03PPC_BNDARY
from .util import NAG_D03PPC_UVINIT
from .util import NAG_D03PPC_ODEDEF
from .util import NAG_D03PPC_MONITF
from .util import NAG_D03PRC_PDEDEF
from .util import NAG_D03PRC_BNDARY
from .util import NAG_D03PRC_UVINIT
from .util import NAG_D03PRC_ODEDEF
from .util import NAG_D03PRC_MONITF
from .util import NAG_D03PSC_PDEDEF
from .util import NAG_D03PSC_NUMFLX
from .util import NAG_D03PSC_BNDARY
from .util import NAG_D03PSC_UVINIT
from .util import NAG_D03PSC_ODEDEF
from .util import NAG_D03PSC_MONITF
from .util import Nag_OptionType
from .util import Nag_MeshType
from .util import NAG_D03PCC_PDEDEF
from .util import NAG_D03PCC_BNDARY
from .util import Nag_D03_Save
from .util import Nag_OsherVersion

STRING = c_char_p

_library_cl = get_library()

d03ncc_ctypes = _library_cl.d03ncc
d03ncc_ctypes.restype = None
d03ncc_ctypes.argtypes = [Nag_OptionType, c_double, Nag_MeshType, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(Nag_Boolean), POINTER(c_double), POINTER(c_double), POINTER(c_double), c_double, Integer, POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def d03ncc(kopt, x, mesh, ns, s, nt, t, tdpar, r, q, sigma, alpha, ntkeep, f, theta, delta, gamma, _lambda, rho, fail):
    """
    Finite difference solution of the Black--Scholes equations.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03ncc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        s, t, tdpar, r, q, sigma, f, theta, delta, gamma, _lambda, rho
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        s, t, r, q, sigma, f, theta, delta, gamma, _lambda, rho
    TypeError will be raised when the following arguments are not of data type
    Nag_Boolean:
        tdpar
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_enum_type_check_and_cast
    _s = nag_double_type_check_and_cast('d03ncc', s, 's')
    _t = nag_double_type_check_and_cast('d03ncc', t, 't')
    _tdpar = nag_enum_type_check_and_cast('d03ncc', tdpar, 'tdpar', Nag_Boolean)
    _r = nag_double_type_check_and_cast('d03ncc', r, 'r')
    _q = nag_double_type_check_and_cast('d03ncc', q, 'q')
    _sigma = nag_double_type_check_and_cast('d03ncc', sigma, 'sigma')
    _f = nag_double_type_check_and_cast('d03ncc', f, 'f')
    _theta = nag_double_type_check_and_cast('d03ncc', theta, 'theta')
    _delta = nag_double_type_check_and_cast('d03ncc', delta, 'delta')
    _gamma = nag_double_type_check_and_cast('d03ncc', gamma, 'gamma')
    __lambda = nag_double_type_check_and_cast('d03ncc', _lambda, '_lambda')
    _rho = nag_double_type_check_and_cast('d03ncc', rho, 'rho')
    d03ncc_ctypes(kopt, x, mesh, ns, _s, nt, _t, _tdpar, _r, _q, _sigma, alpha, ntkeep, _f, _theta, _delta, _gamma, __lambda, _rho, fail)

d03ndc_ctypes = _library_cl.d03ndc
d03ndc_ctypes.restype = None
d03ndc_ctypes.argtypes = [Nag_OptionType, c_double, c_double, c_double, c_double, POINTER(Nag_Boolean), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def d03ndc(kopt, x, s, t, tmat, tdpar, r, q, sigma, f, theta, delta, gamma, _lambda, rho, fail):
    """
    Analytic solution of the Black--Scholes equations.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03ndc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        tdpar, r, q, sigma, f, theta, delta, gamma, _lambda, rho
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        r, q, sigma, f, theta, delta, gamma, _lambda, rho
    TypeError will be raised when the following arguments are not of data type
    Nag_Boolean:
        tdpar
    """
    from .util import nag_enum_type_check_and_cast
    from .util import nag_double_type_check_and_cast
    _tdpar = nag_enum_type_check_and_cast('d03ndc', tdpar, 'tdpar', Nag_Boolean)
    _r = nag_double_type_check_and_cast('d03ndc', r, 'r')
    _q = nag_double_type_check_and_cast('d03ndc', q, 'q')
    _sigma = nag_double_type_check_and_cast('d03ndc', sigma, 'sigma')
    _f = nag_double_type_check_and_cast('d03ndc', f, 'f')
    _theta = nag_double_type_check_and_cast('d03ndc', theta, 'theta')
    _delta = nag_double_type_check_and_cast('d03ndc', delta, 'delta')
    _gamma = nag_double_type_check_and_cast('d03ndc', gamma, 'gamma')
    __lambda = nag_double_type_check_and_cast('d03ndc', _lambda, '_lambda')
    _rho = nag_double_type_check_and_cast('d03ndc', rho, 'rho')
    d03ndc_ctypes(kopt, x, s, t, tmat, _tdpar, _r, _q, _sigma, _f, _theta, _delta, _gamma, __lambda, _rho, fail)

d03nec_ctypes = _library_cl.d03nec
d03nec_ctypes.restype = None
d03nec_ctypes.argtypes = [c_double, c_double, Integer, POINTER(c_double), POINTER(c_double), POINTER(c_double), POINTER(NagError)]


def d03nec(t0, tmat, ntd, td, phid, phiav, fail):
    """
    Compute average values for d03ndc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03nec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        td, phid, phiav
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        td, phid, phiav
    """
    from .util import nag_double_type_check_and_cast
    _td = nag_double_type_check_and_cast('d03nec', td, 'td')
    _phid = nag_double_type_check_and_cast('d03nec', phid, 'phid')
    _phiav = nag_double_type_check_and_cast('d03nec', phiav, 'phiav')
    d03nec_ctypes(t0, tmat, ntd, _td, _phid, _phiav, fail)

d03pcc_ctypes = _library_cl.d03pcc
d03pcc_ctypes.restype = None
d03pcc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), c_double, NAG_D03PCC_PDEDEF, NAG_D03PCC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), c_double, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pcc(npde, m, ts, tout, pdedef, bndary, u, npts, x, acc, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of parabolic PDEs, method of lines, finite differences,
    one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pcc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03pcc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pcc', u, 'u')
    _x = nag_double_type_check_and_cast('d03pcc', x, 'x')
    _rsave = nag_double_type_check_and_cast('d03pcc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pcc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pcc', ind, 'ind')
    d03pcc_ctypes(npde, m, _ts, tout, pdedef, bndary, _u, npts, _x, acc, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03pdc_ctypes = _library_cl.d03pdc
d03pdc_ctypes.restype = None
d03pdc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), c_double, NAG_D03PDC_PDEDEF, NAG_D03PDC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), NAG_D03PDC_UINIT, c_double, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pdc(npde, m, ts, tout, pdedef, bndary, u, nbkpts, xbkpts, npoly, npts, x, uinit, acc, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of parabolic PDEs, method of lines, Chebyshev C**0
    collocation, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pdc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, xbkpts, x, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, xbkpts, x, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03pdc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pdc', u, 'u')
    _xbkpts = nag_double_type_check_and_cast('d03pdc', xbkpts, 'xbkpts')
    _x = nag_double_type_check_and_cast('d03pdc', x, 'x')
    _rsave = nag_double_type_check_and_cast('d03pdc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pdc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pdc', ind, 'ind')
    d03pdc_ctypes(npde, m, _ts, tout, pdedef, bndary, _u, nbkpts, _xbkpts, npoly, npts, _x, uinit, acc, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03pec_ctypes = _library_cl.d03pec
d03pec_ctypes.restype = None
d03pec_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PEC_PDEDEF, NAG_D03PEC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, c_double, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pec(npde, ts, tout, pdedef, bndary, u, npts, x, nleft, acc, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of first-order PDEs, method of lines, Keller box
    discretization, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pec.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03pec', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pec', u, 'u')
    _x = nag_double_type_check_and_cast('d03pec', x, 'x')
    _rsave = nag_double_type_check_and_cast('d03pec', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pec', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pec', ind, 'ind')
    d03pec_ctypes(npde, _ts, tout, pdedef, bndary, _u, npts, _x, nleft, acc, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03pfc_ctypes = _library_cl.d03pfc
d03pfc_ctypes.restype = None
d03pfc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PFC_PDEDEF, NAG_D03PFC_NUMFLX, NAG_D03PFC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), c_double, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pfc(npde, ts, tout, pdedef, numflx, bndary, u, npts, x, acc, tsmax, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of convection-diffusion PDEs with source terms in
    conservative form, method of lines, upwind scheme using numerical flux
    function based on Riemann solver, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pfc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, acc, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, acc, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    if pdedef is None:
        pdedef = cast(None, NAG_D03PFC_PDEDEF)
    _ts = nag_double_type_check_and_cast('d03pfc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pfc', u, 'u')
    _x = nag_double_type_check_and_cast('d03pfc', x, 'x')
    _acc = nag_double_type_check_and_cast('d03pfc', acc, 'acc')
    _rsave = nag_double_type_check_and_cast('d03pfc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pfc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pfc', ind, 'ind')
    d03pfc_ctypes(npde, _ts, tout, pdedef, numflx, bndary, _u, npts, _x, _acc, tsmax, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03phc_ctypes = _library_cl.d03phc
d03phc_ctypes.restype = None
d03phc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), c_double, NAG_D03PHC_PDEDEF, NAG_D03PHC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, NAG_D03PHC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03phc(npde, m, ts, tout, pdedef, bndary, u, npts, x, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of parabolic PDEs, coupled DAEs, method of lines, finite
    differences, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03phc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03phc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03phc', u, 'u')
    _x = nag_double_type_check_and_cast('d03phc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PHC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03phc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03phc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03phc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03phc', algopt, 'algopt')
    _rsave = nag_double_type_check_and_cast('d03phc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03phc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03phc', ind, 'ind')
    d03phc_ctypes(npde, m, _ts, tout, pdedef, bndary, _u, npts, _x, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03pjc_ctypes = _library_cl.d03pjc
d03pjc_ctypes.restype = None
d03pjc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), c_double, NAG_D03PJC_PDEDEF, NAG_D03PJC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), Integer, NAG_D03PJC_ODEDEF, Integer, POINTER(c_double), Integer, NAG_D03PJC_UVINIT, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pjc(npde, m, ts, tout, pdedef, bndary, u, nbkpts, xbkpts, npoly, npts, x, ncode, odedef, nxi, xi, neqn, uvinit, rtol, atol, itol, norm, laopt, algopt, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of parabolic PDEs, coupled DAEs, method of lines,
    Chebyshev C**0 collocation, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pjc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, xbkpts, x, xi, rtol, atol, algopt, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, xbkpts, x, xi, rtol, atol, algopt, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03pjc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pjc', u, 'u')
    _xbkpts = nag_double_type_check_and_cast('d03pjc', xbkpts, 'xbkpts')
    _x = nag_double_type_check_and_cast('d03pjc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PJC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03pjc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03pjc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03pjc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03pjc', algopt, 'algopt')
    _rsave = nag_double_type_check_and_cast('d03pjc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pjc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pjc', ind, 'ind')
    d03pjc_ctypes(npde, m, _ts, tout, pdedef, bndary, _u, nbkpts, _xbkpts, npoly, npts, _x, ncode, odedef, nxi, _xi, neqn, uvinit, _rtol, _atol, itol, norm, laopt, _algopt, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03pkc_ctypes = _library_cl.d03pkc
d03pkc_ctypes.restype = None
d03pkc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PKC_PDEDEF, NAG_D03PKC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, Integer, NAG_D03PKC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pkc(npde, ts, tout, pdedef, bndary, u, npts, x, nleft, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of first-order PDEs, coupled DAEs, method of lines,
    Keller box discretization, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pkc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03pkc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03pkc', u, 'u')
    _x = nag_double_type_check_and_cast('d03pkc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PKC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03pkc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03pkc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03pkc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03pkc', algopt, 'algopt')
    _rsave = nag_double_type_check_and_cast('d03pkc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03pkc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03pkc', ind, 'ind')
    d03pkc_ctypes(npde, _ts, tout, pdedef, bndary, _u, npts, _x, nleft, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03plc_ctypes = _library_cl.d03plc
d03plc_ctypes.restype = None
d03plc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PLC_PDEDEF, NAG_D03PLC_NUMFLX, NAG_D03PLC_BNDARY, POINTER(c_double), Integer, POINTER(c_double), Integer, NAG_D03PLC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03plc(npde, ts, tout, pdedef, numflx, bndary, u, npts, x, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of convection-diffusion PDEs with source terms in
    conservative form, coupled DAEs, method of lines, upwind scheme using
    numerical flux function based on Riemann solver, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03plc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03plc', ts, 'ts')
    if pdedef is None:
        pdedef = cast(None, NAG_D03PLC_PDEDEF)
    _u = nag_double_type_check_and_cast('d03plc', u, 'u')
    _x = nag_double_type_check_and_cast('d03plc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PLC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03plc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03plc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03plc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03plc', algopt, 'algopt')
    _rsave = nag_double_type_check_and_cast('d03plc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03plc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03plc', ind, 'ind')
    d03plc_ctypes(npde, _ts, tout, pdedef, numflx, bndary, _u, npts, _x, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03ppc_ctypes = _library_cl.d03ppc
d03ppc_ctypes.restype = None
d03ppc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), c_double, NAG_D03PPC_PDEDEF, NAG_D03PPC_BNDARY, NAG_D03PPC_UVINIT, POINTER(c_double), Integer, POINTER(c_double), Integer, NAG_D03PPC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), Nag_Boolean, Integer, POINTER(c_double), Integer, c_double, c_double, Integer, c_double, c_double, NAG_D03PPC_MONITF, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03ppc(npde, m, ts, tout, pdedef, bndary, uvinit, u, npts, x, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, remesh, nxfix, xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of parabolic PDEs, coupled DAEs, method of lines, finite
    differences, remeshing, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03ppc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03ppc', ts, 'ts')
    _u = nag_double_type_check_and_cast('d03ppc', u, 'u')
    _x = nag_double_type_check_and_cast('d03ppc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PPC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03ppc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03ppc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03ppc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03ppc', algopt, 'algopt')
    _xfix = nag_double_type_check_and_cast('d03ppc', xfix, 'xfix')
    if monitf is None:
        monitf = cast(None, NAG_D03PPC_MONITF)
    _rsave = nag_double_type_check_and_cast('d03ppc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03ppc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03ppc', ind, 'ind')
    d03ppc_ctypes(npde, m, _ts, tout, pdedef, bndary, uvinit, _u, npts, _x, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, remesh, nxfix, _xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03prc_ctypes = _library_cl.d03prc
d03prc_ctypes.restype = None
d03prc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PRC_PDEDEF, NAG_D03PRC_BNDARY, NAG_D03PRC_UVINIT, POINTER(c_double), Integer, POINTER(c_double), Integer, Integer, NAG_D03PRC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), Nag_Boolean, Integer, POINTER(c_double), Integer, c_double, c_double, Integer, c_double, c_double, NAG_D03PRC_MONITF, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03prc(npde, ts, tout, pdedef, bndary, uvinit, u, npts, x, nleft, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, remesh, nxfix, xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of first-order PDEs, coupled DAEs, method of lines,
    Keller box discretization, remeshing, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03prc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03prc', ts, 'ts')
    if pdedef is None:
        pdedef = cast(None, NAG_D03PRC_PDEDEF)
    _u = nag_double_type_check_and_cast('d03prc', u, 'u')
    _x = nag_double_type_check_and_cast('d03prc', x, 'x')
    _xi = nag_double_type_check_and_cast('d03prc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03prc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03prc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03prc', algopt, 'algopt')
    _xfix = nag_double_type_check_and_cast('d03prc', xfix, 'xfix')
    if monitf is None:
        monitf = cast(None, NAG_D03PRC_MONITF)
    _rsave = nag_double_type_check_and_cast('d03prc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03prc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03prc', ind, 'ind')
    d03prc_ctypes(npde, _ts, tout, pdedef, bndary, uvinit, _u, npts, _x, nleft, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, remesh, nxfix, _xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03psc_ctypes = _library_cl.d03psc
d03psc_ctypes.restype = None
d03psc_ctypes.argtypes = [Integer, POINTER(c_double), c_double, NAG_D03PSC_PDEDEF, NAG_D03PSC_NUMFLX, NAG_D03PSC_BNDARY, NAG_D03PSC_UVINIT, POINTER(c_double), Integer, POINTER(c_double), Integer, NAG_D03PSC_ODEDEF, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Nag_NormType, Nag_LinAlgOption, POINTER(c_double), Nag_Boolean, Integer, POINTER(c_double), Integer, c_double, c_double, Integer, c_double, c_double, NAG_D03PSC_MONITF, POINTER(c_double), Integer, POINTER(Integer), Integer, Integer, Integer, STRING, POINTER(Integer), POINTER(Nag_Comm), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03psc(npde, ts, tout, pdedef, numflx, bndary, uvinit, u, npts, x, ncode, odedef, nxi, xi, neqn, rtol, atol, itol, norm, laopt, algopt, remesh, nxfix, xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, rsave, lrsave, isave, lisave, itask, itrace, outfile, ind, comm, saved, fail):
    """
    General system of convection-diffusion PDEs, coupled DAEs, method of
    lines, upwind scheme, remeshing, one space variable.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03psc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave, isave, ind
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        ts, u, x, xi, rtol, atol, algopt, xfix, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.int32 or numpy.int64:
        isave, ind
    """
    from ctypes import cast
    from .util import nag_double_type_check_and_cast
    from .util import nag_integer_type_check_and_cast
    _ts = nag_double_type_check_and_cast('d03psc', ts, 'ts')
    if pdedef is None:
        pdedef = cast(None, NAG_D03PSC_PDEDEF)
    _u = nag_double_type_check_and_cast('d03psc', u, 'u')
    _x = nag_double_type_check_and_cast('d03psc', x, 'x')
    if odedef is None:
        odedef = cast(None, NAG_D03PSC_ODEDEF)
    _xi = nag_double_type_check_and_cast('d03psc', xi, 'xi')
    _rtol = nag_double_type_check_and_cast('d03psc', rtol, 'rtol')
    _atol = nag_double_type_check_and_cast('d03psc', atol, 'atol')
    _algopt = nag_double_type_check_and_cast('d03psc', algopt, 'algopt')
    _xfix = nag_double_type_check_and_cast('d03psc', xfix, 'xfix')
    if monitf is None:
        monitf = cast(None, NAG_D03PSC_MONITF)
    _rsave = nag_double_type_check_and_cast('d03psc', rsave, 'rsave')
    _isave = nag_integer_type_check_and_cast('d03psc', isave, 'isave')
    _ind = nag_integer_type_check_and_cast('d03psc', ind, 'ind')
    d03psc_ctypes(npde, _ts, tout, pdedef, numflx, bndary, uvinit, _u, npts, _x, ncode, odedef, nxi, _xi, neqn, _rtol, _atol, itol, norm, laopt, _algopt, remesh, nxfix, _xfix, nrmesh, dxmesh, trmesh, ipminf, xratio, con, monitf, _rsave, lrsave, _isave, lisave, itask, itrace, outfile, _ind, comm, saved, fail)

d03puc_ctypes = _library_cl.d03puc
d03puc_ctypes.restype = None
d03puc_ctypes.argtypes = [POINTER(c_double), POINTER(c_double), c_double, POINTER(c_double), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03puc(uleft, uright, gamma, flux, saved, fail):
    """
    Roe's approximate Riemann solver for Euler equations in conservative
    form, for use with d03pfc, d03plc and d03psc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03puc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        uleft, uright, flux
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        uleft, uright, flux
    """
    from .util import nag_double_type_check_and_cast
    _uleft = nag_double_type_check_and_cast('d03puc', uleft, 'uleft')
    _uright = nag_double_type_check_and_cast('d03puc', uright, 'uright')
    _flux = nag_double_type_check_and_cast('d03puc', flux, 'flux')
    d03puc_ctypes(_uleft, _uright, gamma, _flux, saved, fail)

d03pvc_ctypes = _library_cl.d03pvc
d03pvc_ctypes.restype = None
d03pvc_ctypes.argtypes = [POINTER(c_double), POINTER(c_double), c_double, Nag_OsherVersion, POINTER(c_double), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pvc(uleft, uright, gamma, path, flux, saved, fail):
    """
    Osher's approximate Riemann solver for Euler equations in conservative
    form, for use with d03pfc, d03plc and d03psc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pvc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        uleft, uright, flux
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        uleft, uright, flux
    """
    from .util import nag_double_type_check_and_cast
    _uleft = nag_double_type_check_and_cast('d03pvc', uleft, 'uleft')
    _uright = nag_double_type_check_and_cast('d03pvc', uright, 'uright')
    _flux = nag_double_type_check_and_cast('d03pvc', flux, 'flux')
    d03pvc_ctypes(_uleft, _uright, gamma, path, _flux, saved, fail)

d03pwc_ctypes = _library_cl.d03pwc
d03pwc_ctypes.restype = None
d03pwc_ctypes.argtypes = [POINTER(c_double), POINTER(c_double), c_double, POINTER(c_double), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pwc(uleft, uright, gamma, flux, saved, fail):
    """
    Modified HLL Riemann solver for Euler equations in conservative form,
    for use with d03pfc, d03plc and d03psc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pwc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        uleft, uright, flux
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        uleft, uright, flux
    """
    from .util import nag_double_type_check_and_cast
    _uleft = nag_double_type_check_and_cast('d03pwc', uleft, 'uleft')
    _uright = nag_double_type_check_and_cast('d03pwc', uright, 'uright')
    _flux = nag_double_type_check_and_cast('d03pwc', flux, 'flux')
    d03pwc_ctypes(_uleft, _uright, gamma, _flux, saved, fail)

d03pxc_ctypes = _library_cl.d03pxc
d03pxc_ctypes.restype = None
d03pxc_ctypes.argtypes = [POINTER(c_double), POINTER(c_double), c_double, c_double, Integer, POINTER(c_double), POINTER(Nag_D03_Save), POINTER(NagError)]


def d03pxc(uleft, uright, gamma, tol, niter, flux, saved, fail):
    """
    Exact Riemann solver for Euler equations in conservative form, for use
    with d03pfc, d03plc and d03psc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pxc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        uleft, uright, flux
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        uleft, uright, flux
    """
    from .util import nag_double_type_check_and_cast
    _uleft = nag_double_type_check_and_cast('d03pxc', uleft, 'uleft')
    _uright = nag_double_type_check_and_cast('d03pxc', uright, 'uright')
    _flux = nag_double_type_check_and_cast('d03pxc', flux, 'flux')
    d03pxc_ctypes(_uleft, _uright, gamma, tol, niter, _flux, saved, fail)

d03pyc_ctypes = _library_cl.d03pyc
d03pyc_ctypes.restype = None
d03pyc_ctypes.argtypes = [Integer, POINTER(c_double), Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), Integer, Integer, POINTER(c_double), POINTER(c_double), Integer, POINTER(NagError)]


def d03pyc(npde, u, nbkpts, xbkpts, npoly, npts, xp, intpts, itype, up, rsave, lrsave, fail):
    """
    PDEs, spatial interpolation with d03pdc or d03pjc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pyc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        u, xbkpts, xp, up, rsave
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        u, xbkpts, xp, up, rsave
    """
    from .util import nag_double_type_check_and_cast
    _u = nag_double_type_check_and_cast('d03pyc', u, 'u')
    _xbkpts = nag_double_type_check_and_cast('d03pyc', xbkpts, 'xbkpts')
    _xp = nag_double_type_check_and_cast('d03pyc', xp, 'xp')
    _up = nag_double_type_check_and_cast('d03pyc', up, 'up')
    _rsave = nag_double_type_check_and_cast('d03pyc', rsave, 'rsave')
    d03pyc_ctypes(npde, _u, nbkpts, _xbkpts, npoly, npts, _xp, intpts, itype, _up, _rsave, lrsave, fail)

d03pzc_ctypes = _library_cl.d03pzc
d03pzc_ctypes.restype = None
d03pzc_ctypes.argtypes = [Integer, Integer, POINTER(c_double), Integer, POINTER(c_double), POINTER(c_double), Integer, Integer, POINTER(c_double), POINTER(NagError)]


def d03pzc(npde, m, u, npts, x, xp, intpts, itype, up, fail):
    """
    PDEs, spatial interpolation with d03pcc, d03pec, d03pfc, d03phc, d03pkc,
    d03plc, d03ppc, d03prc or d03psc.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/d03/d03pzc.html

    TypeError will be raised when the following arguments are not instances
    of numpy.ndarray:
        u, x, xp, up
    TypeError will be raised when the following arguments are not of data type
    numpy.float:
        u, x, xp, up
    """
    from .util import nag_double_type_check_and_cast
    _u = nag_double_type_check_and_cast('d03pzc', u, 'u')
    _x = nag_double_type_check_and_cast('d03pzc', x, 'x')
    _xp = nag_double_type_check_and_cast('d03pzc', xp, 'xp')
    _up = nag_double_type_check_and_cast('d03pzc', up, 'up')
    d03pzc_ctypes(npde, m, _u, npts, _x, _xp, intpts, itype, _up, fail)

nag_pde_bs_1d = d03ncc
nag_pde_bs_1d_analytic = d03ndc
nag_pde_bs_1d_means = d03nec
nag_pde_parab_1d_fd = d03pcc
nag_pde_parab_1d_coll = d03pdc
nag_pde_parab_1d_keller = d03pec
nag_pde_parab_1d_cd = d03pfc
nag_pde_parab_1d_fd_ode = d03phc
nag_pde_parab_1d_coll_ode = d03pjc
nag_pde_parab_1d_keller_ode = d03pkc
nag_pde_parab_1d_cd_ode = d03plc
nag_pde_parab_1d_fd_ode_remesh = d03ppc
nag_pde_parab_1d_keller_ode_remesh = d03prc
nag_pde_parab_1d_cd_ode_remesh = d03psc
nag_pde_parab_1d_euler_roe = d03puc
nag_pde_parab_1d_euler_osher = d03pvc
nag_pde_parab_1d_euler_hll = d03pwc
nag_pde_parab_1d_euler_exact = d03pxc
nag_pde_interp_1d_coll = d03pyc
nag_pde_interp_1d_fd = d03pzc
__all__ = ['d03ncc', 'd03ndc', 'd03nec', 'd03pcc', 'd03pdc', 'd03pec',
           'd03pfc', 'd03phc', 'd03pjc', 'd03pkc', 'd03plc', 'd03ppc',
           'd03prc', 'd03psc', 'd03puc', 'd03pvc', 'd03pwc', 'd03pxc',
           'd03pyc', 'd03pzc',
           'nag_pde_bs_1d', 'nag_pde_bs_1d_analytic',
           'nag_pde_bs_1d_means', 'nag_pde_interp_1d_coll',
           'nag_pde_interp_1d_fd', 'nag_pde_parab_1d_cd',
           'nag_pde_parab_1d_cd_ode',
           'nag_pde_parab_1d_cd_ode_remesh', 'nag_pde_parab_1d_coll',
           'nag_pde_parab_1d_coll_ode',
           'nag_pde_parab_1d_euler_exact',
           'nag_pde_parab_1d_euler_hll',
           'nag_pde_parab_1d_euler_osher',
           'nag_pde_parab_1d_euler_roe', 'nag_pde_parab_1d_fd',
           'nag_pde_parab_1d_fd_ode',
           'nag_pde_parab_1d_fd_ode_remesh',
           'nag_pde_parab_1d_keller', 'nag_pde_parab_1d_keller_ode',
           'nag_pde_parab_1d_keller_ode_remesh']
