"""
Deprecated wrappers for the NAG C Library (Mark 26.0) x02 Chapter.

x02 - Machine Constants.

https://www.nag.com/numeric/CL/nagdoc_cl26/html/X02/x02conts.html

NAG Copyright 2017.
"""
from ctypes import c_double
from .util import get_library
from .util import Integer

_library_cl = get_library()

x02ahc_ctypes = _library_cl.x02ahc
x02ahc_ctypes.restype = c_double
x02ahc_ctypes.argtypes = []

def x02ahc():
    """
    The largest permissible argument for sin and cos.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02ahc.html
    """
    return_value = x02ahc_ctypes()
    return return_value

x02ajc_ctypes = _library_cl.x02ajc
x02ajc_ctypes.restype = c_double
x02ajc_ctypes.argtypes = []

def x02ajc():
    """
    The machine precision.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02ajc.html
    """
    return_value = x02ajc_ctypes()
    return return_value

x02akc_ctypes = _library_cl.x02akc
x02akc_ctypes.restype = c_double
x02akc_ctypes.argtypes = []

def x02akc():
    """
    The smallest positive model number.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02akc.html
    """
    return_value = x02akc_ctypes()
    return return_value

x02alc_ctypes = _library_cl.x02alc
x02alc_ctypes.restype = c_double
x02alc_ctypes.argtypes = []

def x02alc():
    """
    The largest positive model number.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02alc.html
    """
    return_value = x02alc_ctypes()
    return return_value

x02amc_ctypes = _library_cl.x02amc
x02amc_ctypes.restype = c_double
x02amc_ctypes.argtypes = []

def x02amc():
    """
    Safe range of floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02amc.html
    """
    return_value = x02amc_ctypes()
    return return_value

x02anc_ctypes = _library_cl.x02anc
x02anc_ctypes.restype = c_double
x02anc_ctypes.argtypes = []

def x02anc():
    """
    Safe range of NAG complex floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02anc.html
    """
    return_value = x02anc_ctypes()
    return return_value

x02bbc_ctypes = _library_cl.x02bbc
x02bbc_ctypes.restype = Integer
x02bbc_ctypes.argtypes = []

def x02bbc():
    """
    The largest representable integer.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02bbc.html
    """
    return_value = x02bbc_ctypes()
    return return_value

x02bec_ctypes = _library_cl.x02bec
x02bec_ctypes.restype = Integer
x02bec_ctypes.argtypes = []

def x02bec():
    """
    The maximum number of decimal digits that can be represented.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02bec.html
    """
    return_value = x02bec_ctypes()
    return return_value

x02bhc_ctypes = _library_cl.x02bhc
x02bhc_ctypes.restype = Integer
x02bhc_ctypes.argtypes = []

def x02bhc():
    """
    Parameter b of model of floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02bhc.html
    """
    return_value = x02bhc_ctypes()
    return return_value

x02bjc_ctypes = _library_cl.x02bjc
x02bjc_ctypes.restype = Integer
x02bjc_ctypes.argtypes = []

def x02bjc():
    """
    Parameter p of model of floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02bjc.html
    """
    return_value = x02bjc_ctypes()
    return return_value

x02bkc_ctypes = _library_cl.x02bkc
x02bkc_ctypes.restype = Integer
x02bkc_ctypes.argtypes = []

def x02bkc():
    """
    Parameter e_min of model of floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02bkc.html
    """
    return_value = x02bkc_ctypes()
    return return_value

x02blc_ctypes = _library_cl.x02blc
x02blc_ctypes.restype = Integer
x02blc_ctypes.argtypes = []

def x02blc():
    """
    Parameter e_max of model of floating-point arithmetic.
    https://www.nag.com/numeric/CL/nagdoc_cl26/html/x02/x02blc.html
    """
    return_value = x02blc_ctypes()
    return return_value

nag_max_sine_argument = X02AHC = x02ahc()
nag_machine_precision = X02AJC = x02ajc()
nag_real_smallest_number = X02AKC = x02akc()
nag_real_largest_number = X02ALC = x02alc()
nag_real_safe_small_number = X02AMC = x02amc()
nag_complex_safe_small_number = X02ANC = x02anc()
nag_max_integer = X02BBC = x02bbc()
nag_decimal_digits = X02BEC = x02bec()
nag_real_base = X02BHC = x02bhc()
nag_real_base_digits = X02BJC = x02bjc()
nag_real_min_exponent = X02BKC = x02bkc()
nag_real_max_exponent = X02BLC = x02blc()
__all__ = ['nag_complex_safe_small_number', 'nag_decimal_digits',
           'nag_machine_precision', 'nag_max_integer',
           'nag_max_sine_argument', 'nag_real_base',
           'nag_real_base_digits', 'nag_real_largest_number',
           'nag_real_max_exponent', 'nag_real_min_exponent',
           'nag_real_safe_small_number', 'nag_real_smallest_number',
           'x02ahc', 'x02ajc', 'x02akc', 'x02alc', 'x02amc', 'x02anc',
           'x02bbc', 'x02bec', 'x02bhc', 'x02bjc', 'x02bkc', 'x02blc']
